' SmartGetSizes_Handler:
' Revision: v1.2.2 (vb)
' (c) 2015 steje
'
' This is a script for written for Directory Opus v11.
' See http://www.gpsoft.com.au/redirect.asp?page=scripts for development information.

' =====================================================================================
' ======================   EVENT HANDLER: OnAfterFolderChange   =======================
'
' This script is intended as an alternative to toggling the 'Calculate folder sizes
' automatically' option in Prefs via the 'Set CALCFOLDERSIZES' command.
'
' The difference between this scripts behavior and the 'Set CALCFOLDERSIZES' command
' is that toggling the option in Prefs affects ALL listers, whereas this script is
' currently lister specific. It works as an event handler for the OnAfterFolderChange
' event, such that when a folder change is made - the script checks if a lister scoped
' variable named 'autosize' is set. If the variable is set, then the folder sizes are
' calculated automatically.
'
' Here is an example toolbar button code snippet to toggle the variable required to
' control the scripts behavior:
'
'                        @toggle:if $lst:autosize
'
'                        @ifset:$lst:autosize
'                        @set lst:autosize
'
'                        @ifset:else
'                        @set lst:autosize=true
'                        SmartGetSizes GETALL NODESELECT
'
' Note that the example button code above operates in LISTER scope (lst: prefix), but
' the script supports GLOBAL (glob:) and source TAB (src:) scopes as well.
'
' Both the example button code above AND this scripts main function rely on the use of
' the 'SmartGetSizes' command. That command is made available to Opus by the additional
' Script Command packaged together with this script as ScriptCommand_smartgetsizes.
' Check the Script Commands own comments and description for details on its use. It is
' inspired by code provided by Jonathan Potter to solve a users request for modified
' 'GetSizes' behavior. It is used in the example button code above so that when the
' button is pressed to toggle 'On' the environment variable that controls this scripts
' behavior, it also then calculates the 'current' tabs folder sizes (before any folder
' changes are made), regardless of either file/folder selection state or whether any
' selected folders have already had theirs sizes calculated or not.
'
' This version of the script currently operates on any type of folder, and does not
' currently offer the granularity of control of the actual Prefs option...
'
' =====================================================================================

Option Explicit
Dim SCRIPT_DEBUG
SCRIPT_DEBUG = False


'//////////////////////////////////////////////////////////////////////////////////////////////////
' Called by Directory Opus to initialize the script
Function OnInit(ByRef initData)

   DOpus.Output("Initializing...")

   ' Provide basic information about the Script
   initData.min_version = "11.16"
   initData.name = "SmartGetSizes_Handler"
   initData.desc = "Check for lister variable on folder changes to auto-calculate folder sizes or not."
   initData.copyright = "(c) 2015 steje"
   initData.version = "v1.2.2 (vb)"
   initData.default_enable = true

   '////////////////////////////////////////////////
   ' The following options are user configurable via the Configure button under the scripts listing in Prefs
   '////////////////////////////////////////////////
   ' Set DEBUG flag to True in order to enable logging messages to the Opus Output Window
   initData.config.DEBUG = False
   '////////////////////////////////////////////////
   ' Set DEBUG_CLEAR flag to True in order to clear log messages from the Opus Output Window between script runs
   initData.config.DEBUG_CLEAR = False
   '////////////////////////////////////////////////
   ' Set descriptions for all script options
   initData.config_desc = DOpus.NewMap("DEBUG", "Set this option to True to enable logging to the Opus script log.", _
                                       "DEBUG_CLEAR", "Set this option to True clear messages logged to the Opus script log between script runs.")

End Function


'//////////////////////////////////////////////////////////////////////////////////////////////////
' Called after the folder has been changed
Function OnAfterFolderChange(ByRef afterFolderChangeData)
   Dim objCmd

   Set objCmd = DOpus.NewCommand
   If (objCmd.IsSet("$glob:SCRIPT_DEBUG")) Then SCRIPT_DEBUG = True
   If ((Script.config.DEBUG) Or (SCRIPT_DEBUG)) And (Script.config.DEBUG_CLEAR) Then DOpus.ClearOutput
   'logMsg("OnAfterFolderChange()")

   logMsg("")
   logMsg("----------------------------------------------------------------")
   logMsg("OnAfterFolderChange:  " & afterFolderChangeData.tab.path)
   logMsg("----------------------------------------------------------------")
   ' Check if the folder read was successful
   If (afterFolderChangeData.result) Then
      objCmd.SetSourceTab(afterFolderChangeData.tab)

      If (objCmd.IsSet("$glob:autosize")) Then
         'logMsg("[autosize] is set: [global]")
      ElseIf (objCmd.IsSet("$lst:autosize")) Then
         'logMsg("[autosize] is set: [lister]")
      ElseIf (objCmd.IsSet("$src:autosize")) Then
         'logMsg("[autosize] is set: [source tab]")
      Else
         logMsg("No 'autosize' variable set, exit...")
         Set objCmd = Nothing
         Exit Function
      End If

      objCmd.RunCommand("SmartGetSizes GETALL")
      Set objCmd = Nothing

   End If

End Function


'//////////////////////////////////////////////////////////////////////////////////////////////////
' Subroutine that uses DEBUG variables to control whether logging is performed or not
Sub logMsg(ByRef message)

   If ((Script.config.DEBUG) Or (SCRIPT_DEBUG)) Then DOpus.Output(message)

End Sub
